@@ -1,7 +1,8 @@
 #!/usr/bin/env python
-from xunitparser import parse
 from unittest import TestCase
 
+from xunitparser import parse
+
 
 class X(object):
     def setUp(self):
@@ -31,17 +32,20 @@ class X(object):
                     assert 'backend.pastebin_loggedin' in test.alltext
                     assert 'python2.7' in test.alltext
             if test.methodname == '003-passed-test':
-                assert "system output" in test.stdall
-                assert "error output" in test.stdall
-                assert "system output" in test.stdout
-                assert "error output" in test.stderr
+                assert "testcase system output" in test.stdall
+                assert "testcase error output" in test.stdall
+                assert "testcase system output" in test.stdout
+                assert "testcase error output" in test.stderr
+                assert "testsuite system output" in self.ts.stdout
+                assert "testsuite error output" in self.ts.stderr
 
     def test_hashes(self):
         """ assert hashes are unique """
         assert len(list(hash(t) for t in self.ts)) == len(set(hash(t) for t in self.ts))
 
     def test_testresult(self):
-        assert len(self.tr.failures)
+        if self.FILENAME != 'test5.xml':
+            assert len(self.tr.failures)
         for f in self.tr.failures:
             if 'pastebin.test.PastebinTest' in repr(f[0]):
                 assert 'backend.pastebin_loggedin' in f[1]
@@ -93,3 +97,17 @@ class Test4(X, TestCase):
 
     def test_testsuite_package_has_been_parsed(self):
         assert self.ts.package == 'testdb'
+
+
+class Test5(X, TestCase):
+    FILENAME = 'test5.xml'
+
+    def test_message(self):
+        found = False
+        for test in self.ts:
+            if test.bad:
+                assert test.errored
+                assert 'The step timed out' in test.message
+                assert 'PathToMyProject' in test.trace
+                found = True
+        assert found
